@@ -1,34 +1,39 @@
 #[doc(hidden)]
 #[repr(transparent)]
-pub struct IApplicationProfileStatics(::windows::core::IUnknown);
-unsafe impl ::windows::core::Vtable for IApplicationProfileStatics {
+pub struct IApplicationProfileStatics(::windows_core::IUnknown);
+unsafe impl ::windows_core::Interface for IApplicationProfileStatics {
     type Vtable = IApplicationProfileStatics_Vtbl;
 }
-unsafe impl ::windows::core::Interface for IApplicationProfileStatics {
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xd5008ab4_7e7a_11e1_a7f2_b0a14824019b);
+impl ::core::clone::Clone for IApplicationProfileStatics {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+unsafe impl ::windows_core::ComInterface for IApplicationProfileStatics {
+    const IID: ::windows_core::GUID = ::windows_core::GUID::from_u128(0xd5008ab4_7e7a_11e1_a7f2_b0a14824019b);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IApplicationProfileStatics_Vtbl {
-    pub base__: ::windows::core::IInspectable_Vtbl,
-    pub Modes: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ApplicationProfileModes) -> ::windows::core::HRESULT,
+    pub base__: ::windows_core::IInspectable_Vtbl,
+    pub Modes: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ApplicationProfileModes) -> ::windows_core::HRESULT,
 }
 #[doc = "*Required features: `\"Phone_ApplicationModel\"`*"]
 pub struct ApplicationProfile;
 impl ApplicationProfile {
-    pub fn Modes() -> ::windows::core::Result<ApplicationProfileModes> {
+    pub fn Modes() -> ::windows_core::Result<ApplicationProfileModes> {
         Self::IApplicationProfileStatics(|this| unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).Modes)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<ApplicationProfileModes>(result__)
+            let mut result__ = ::std::mem::zeroed();
+            (::windows_core::Interface::vtable(this).Modes)(::windows_core::Interface::as_raw(this), &mut result__).from_abi(result__)
         })
     }
     #[doc(hidden)]
-    pub fn IApplicationProfileStatics<R, F: FnOnce(&IApplicationProfileStatics) -> ::windows::core::Result<R>>(callback: F) -> ::windows::core::Result<R> {
-        static SHARED: ::windows::core::FactoryCache<ApplicationProfile, IApplicationProfileStatics> = ::windows::core::FactoryCache::new();
+    pub fn IApplicationProfileStatics<R, F: FnOnce(&IApplicationProfileStatics) -> ::windows_core::Result<R>>(callback: F) -> ::windows_core::Result<R> {
+        static SHARED: ::windows_core::imp::FactoryCache<ApplicationProfile, IApplicationProfileStatics> = ::windows_core::imp::FactoryCache::new();
         SHARED.call(callback)
     }
 }
-impl ::windows::core::RuntimeName for ApplicationProfile {
+impl ::windows_core::RuntimeName for ApplicationProfile {
     const NAME: &'static str = "Windows.Phone.ApplicationModel.ApplicationProfile";
 }
 #[doc = "*Required features: `\"Phone_ApplicationModel\"`*"]
@@ -50,14 +55,19 @@ impl ::core::default::Default for ApplicationProfileModes {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for ApplicationProfileModes {
-    type Abi = Self;
+impl ::windows_core::TypeKind for ApplicationProfileModes {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::fmt::Debug for ApplicationProfileModes {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("ApplicationProfileModes").field(&self.0).finish()
     }
 }
+impl ApplicationProfileModes {
+    pub const fn contains(&self, other: Self) -> bool {
+        self.0 & other.0 == other.0
+    }
+}
 impl ::core::ops::BitOr for ApplicationProfileModes {
     type Output = Self;
     fn bitor(self, other: Self) -> Self {
@@ -86,12 +96,6 @@ impl ::core::ops::Not for ApplicationProfileModes {
         Self(self.0.not())
     }
 }
-unsafe impl ::windows::core::RuntimeType for ApplicationProfileModes {
-    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Phone.ApplicationModel.ApplicationProfileModes;u4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
+impl ::windows_core::RuntimeType for ApplicationProfileModes {
+    const SIGNATURE: ::windows_core::imp::ConstBuffer = ::windows_core::imp::ConstBuffer::from_slice(b"enum(Windows.Phone.ApplicationModel.ApplicationProfileModes;u4)");
 }
-#[cfg(feature = "implement")]
-::core::include!("impl.rs");
