@@ -2,11 +2,248 @@
 pub const ComponentTypeEnforcementClientRp: u32 = 2u32;
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
 pub const ComponentTypeEnforcementClientSoH: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const extendedIsolationStateInfected: ExtendedIsolationState = ExtendedIsolationState(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const extendedIsolationStateNoData: ExtendedIsolationState = ExtendedIsolationState(0i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const extendedIsolationStateTransition: ExtendedIsolationState = ExtendedIsolationState(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const extendedIsolationStateUnknown: ExtendedIsolationState = ExtendedIsolationState(3i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryClientCommunication: FailureCategory = FailureCategory(3i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryClientComponent: FailureCategory = FailureCategory(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryCount: u32 = 5u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryNone: FailureCategory = FailureCategory(0i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryOther: FailureCategory = FailureCategory(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryServerCommunication: FailureCategory = FailureCategory(5i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const failureCategoryServerComponent: FailureCategory = FailureCategory(4i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const fixupStateCouldNotUpdate: FixupState = FixupState(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const fixupStateInProgress: FixupState = FixupState(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const fixupStateSuccess: FixupState = FixupState(0i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const freshSoHRequest: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const isolationStateInProbation: IsolationState = IsolationState(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const isolationStateNotRestricted: IsolationState = IsolationState(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const isolationStateRestrictedAccess: IsolationState = IsolationState(3i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxConnectionCountPerEnforcer: u32 = 20u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxEnforcerCount: u32 = 20u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxNetworkSoHSize: u32 = 4000u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxPrivateDataSize: u32 = 200u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxSoHAttributeCount: u32 = 100u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxSoHAttributeSize: u32 = 4000u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxStringLength: u32 = 1024u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const maxSystemHealthEntityCount: u32 = 20u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const minNetworkSoHSize: u32 = 12u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const napNotifyTypeQuarState: NapNotifyType = NapNotifyType(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const napNotifyTypeServiceState: NapNotifyType = NapNotifyType(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const napNotifyTypeUnknown: NapNotifyType = NapNotifyType(0i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const percentageNotSupported: u32 = 101u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const remoteConfigTypeConfigBlob: RemoteConfigurationType = RemoteConfigurationType(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const remoteConfigTypeMachine: RemoteConfigurationType = RemoteConfigurationType(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const shaFixup: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const tracingLevelAdvanced: NapTracingLevel = NapTracingLevel(2i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const tracingLevelBasic: NapTracingLevel = NapTracingLevel(1i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const tracingLevelDebug: NapTracingLevel = NapTracingLevel(3i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+pub const tracingLevelUndefined: NapTracingLevel = NapTracingLevel(0i32);
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct ExtendedIsolationState(pub i32);
+impl ::core::marker::Copy for ExtendedIsolationState {}
+impl ::core::clone::Clone for ExtendedIsolationState {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for ExtendedIsolationState {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for ExtendedIsolationState {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for ExtendedIsolationState {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("ExtendedIsolationState").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct FailureCategory(pub i32);
+impl ::core::marker::Copy for FailureCategory {}
+impl ::core::clone::Clone for FailureCategory {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for FailureCategory {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for FailureCategory {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for FailureCategory {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("FailureCategory").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct FixupState(pub i32);
+impl ::core::marker::Copy for FixupState {}
+impl ::core::clone::Clone for FixupState {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for FixupState {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for FixupState {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for FixupState {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("FixupState").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct IsolationState(pub i32);
+impl ::core::marker::Copy for IsolationState {}
+impl ::core::clone::Clone for IsolationState {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for IsolationState {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for IsolationState {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for IsolationState {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("IsolationState").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct NapNotifyType(pub i32);
+impl ::core::marker::Copy for NapNotifyType {}
+impl ::core::clone::Clone for NapNotifyType {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for NapNotifyType {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for NapNotifyType {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for NapNotifyType {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("NapNotifyType").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct NapTracingLevel(pub i32);
+impl ::core::marker::Copy for NapTracingLevel {}
+impl ::core::clone::Clone for NapTracingLevel {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for NapTracingLevel {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for NapTracingLevel {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for NapTracingLevel {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("NapTracingLevel").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct RemoteConfigurationType(pub i32);
+impl ::core::marker::Copy for RemoteConfigurationType {}
+impl ::core::clone::Clone for RemoteConfigurationType {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for RemoteConfigurationType {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+impl ::windows_core::TypeKind for RemoteConfigurationType {
+    type TypeKind = ::windows_core::CopyType;
+}
+impl ::core::fmt::Debug for RemoteConfigurationType {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("RemoteConfigurationType").field(&self.0).finish()
+    }
+}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct CorrelationId {
-    pub connId: ::windows::core::GUID,
+    pub connId: ::windows_core::GUID,
     pub timeStamp: super::super::Foundation::FILETIME,
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -24,13 +261,13 @@ impl ::core::fmt::Debug for CorrelationId {
     }
 }
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for CorrelationId {
-    type Abi = Self;
+impl ::windows_core::TypeKind for CorrelationId {
+    type TypeKind = ::windows_core::CopyType;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for CorrelationId {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<CorrelationId>()) == 0 }
+        self.connId == other.connId && self.timeStamp == other.timeStamp
     }
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -45,7 +282,7 @@ impl ::core::default::Default for CorrelationId {
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
 pub struct CountedString {
     pub length: u16,
-    pub string: ::windows::core::PWSTR,
+    pub string: ::windows_core::PWSTR,
 }
 impl ::core::marker::Copy for CountedString {}
 impl ::core::clone::Clone for CountedString {
@@ -58,12 +295,12 @@ impl ::core::fmt::Debug for CountedString {
         f.debug_struct("CountedString").field("length", &self.length).field("string", &self.string).finish()
     }
 }
-unsafe impl ::windows::core::Abi for CountedString {
-    type Abi = Self;
+impl ::windows_core::TypeKind for CountedString {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for CountedString {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<CountedString>()) == 0 }
+        self.length == other.length && self.string == other.string
     }
 }
 impl ::core::cmp::Eq for CountedString {}
@@ -72,72 +309,6 @@ impl ::core::default::Default for CountedString {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct ExtendedIsolationState(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const extendedIsolationStateNoData: ExtendedIsolationState = ExtendedIsolationState(0i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const extendedIsolationStateTransition: ExtendedIsolationState = ExtendedIsolationState(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const extendedIsolationStateInfected: ExtendedIsolationState = ExtendedIsolationState(2i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const extendedIsolationStateUnknown: ExtendedIsolationState = ExtendedIsolationState(3i32);
-impl ::core::marker::Copy for ExtendedIsolationState {}
-impl ::core::clone::Clone for ExtendedIsolationState {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for ExtendedIsolationState {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for ExtendedIsolationState {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for ExtendedIsolationState {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("ExtendedIsolationState").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct FailureCategory(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryNone: FailureCategory = FailureCategory(0i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryOther: FailureCategory = FailureCategory(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryClientComponent: FailureCategory = FailureCategory(2i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryClientCommunication: FailureCategory = FailureCategory(3i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryServerComponent: FailureCategory = FailureCategory(4i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryServerCommunication: FailureCategory = FailureCategory(5i32);
-impl ::core::marker::Copy for FailureCategory {}
-impl ::core::clone::Clone for FailureCategory {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for FailureCategory {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for FailureCategory {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for FailureCategory {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("FailureCategory").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -159,13 +330,13 @@ impl ::core::fmt::Debug for FailureCategoryMapping {
     }
 }
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for FailureCategoryMapping {
-    type Abi = Self;
+impl ::windows_core::TypeKind for FailureCategoryMapping {
+    type TypeKind = ::windows_core::CopyType;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for FailureCategoryMapping {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<FailureCategoryMapping>()) == 0 }
+        self.mappingCompliance == other.mappingCompliance
     }
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -195,12 +366,12 @@ impl ::core::fmt::Debug for FixupInfo {
         f.debug_struct("FixupInfo").field("state", &self.state).field("percentage", &self.percentage).field("resultCodes", &self.resultCodes).field("fixupMsgId", &self.fixupMsgId).finish()
     }
 }
-unsafe impl ::windows::core::Abi for FixupInfo {
-    type Abi = Self;
+impl ::windows_core::TypeKind for FixupInfo {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for FixupInfo {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<FixupInfo>()) == 0 }
+        self.state == other.state && self.percentage == other.percentage && self.resultCodes == other.resultCodes && self.fixupMsgId == other.fixupMsgId
     }
 }
 impl ::core::cmp::Eq for FixupInfo {}
@@ -209,35 +380,6 @@ impl ::core::default::Default for FixupInfo {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct FixupState(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const fixupStateSuccess: FixupState = FixupState(0i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const fixupStateInProgress: FixupState = FixupState(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const fixupStateCouldNotUpdate: FixupState = FixupState(2i32);
-impl ::core::marker::Copy for FixupState {}
-impl ::core::clone::Clone for FixupState {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for FixupState {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for FixupState {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for FixupState {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("FixupState").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
 pub struct Ipv4Address {
@@ -254,12 +396,12 @@ impl ::core::fmt::Debug for Ipv4Address {
         f.debug_struct("Ipv4Address").field("addr", &self.addr).finish()
     }
 }
-unsafe impl ::windows::core::Abi for Ipv4Address {
-    type Abi = Self;
+impl ::windows_core::TypeKind for Ipv4Address {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for Ipv4Address {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Ipv4Address>()) == 0 }
+        self.addr == other.addr
     }
 }
 impl ::core::cmp::Eq for Ipv4Address {}
@@ -284,12 +426,12 @@ impl ::core::fmt::Debug for Ipv6Address {
         f.debug_struct("Ipv6Address").field("addr", &self.addr).finish()
     }
 }
-unsafe impl ::windows::core::Abi for Ipv6Address {
-    type Abi = Self;
+impl ::windows_core::TypeKind for Ipv6Address {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for Ipv6Address {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Ipv6Address>()) == 0 }
+        self.addr == other.addr
     }
 }
 impl ::core::cmp::Eq for Ipv6Address {}
@@ -321,13 +463,13 @@ impl ::core::fmt::Debug for IsolationInfo {
     }
 }
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for IsolationInfo {
-    type Abi = Self;
+impl ::windows_core::TypeKind for IsolationInfo {
+    type TypeKind = ::windows_core::CopyType;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for IsolationInfo {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<IsolationInfo>()) == 0 }
+        self.isolationState == other.isolationState && self.probEndTime == other.probEndTime && self.failureUrl == other.failureUrl
     }
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -362,13 +504,13 @@ impl ::core::fmt::Debug for IsolationInfoEx {
     }
 }
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for IsolationInfoEx {
-    type Abi = Self;
+impl ::windows_core::TypeKind for IsolationInfoEx {
+    type TypeKind = ::windows_core::CopyType;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for IsolationInfoEx {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<IsolationInfoEx>()) == 0 }
+        self.isolationState == other.isolationState && self.extendedIsolationState == other.extendedIsolationState && self.probEndTime == other.probEndTime && self.failureUrl == other.failureUrl
     }
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -379,35 +521,6 @@ impl ::core::default::Default for IsolationInfoEx {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct IsolationState(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const isolationStateNotRestricted: IsolationState = IsolationState(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const isolationStateInProbation: IsolationState = IsolationState(2i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const isolationStateRestrictedAccess: IsolationState = IsolationState(3i32);
-impl ::core::marker::Copy for IsolationState {}
-impl ::core::clone::Clone for IsolationState {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for IsolationState {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for IsolationState {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for IsolationState {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("IsolationState").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -417,8 +530,8 @@ pub struct NapComponentRegistrationInfo {
     pub description: CountedString,
     pub version: CountedString,
     pub vendorName: CountedString,
-    pub infoClsid: ::windows::core::GUID,
-    pub configClsid: ::windows::core::GUID,
+    pub infoClsid: ::windows_core::GUID,
+    pub configClsid: ::windows_core::GUID,
     pub registrationDate: super::super::Foundation::FILETIME,
     pub componentType: u32,
 }
@@ -437,13 +550,13 @@ impl ::core::fmt::Debug for NapComponentRegistrationInfo {
     }
 }
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for NapComponentRegistrationInfo {
-    type Abi = Self;
+impl ::windows_core::TypeKind for NapComponentRegistrationInfo {
+    type TypeKind = ::windows_core::CopyType;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for NapComponentRegistrationInfo {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NapComponentRegistrationInfo>()) == 0 }
+        self.id == other.id && self.friendlyName == other.friendlyName && self.description == other.description && self.version == other.version && self.vendorName == other.vendorName && self.infoClsid == other.infoClsid && self.configClsid == other.configClsid && self.registrationDate == other.registrationDate && self.componentType == other.componentType
     }
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -454,66 +567,6 @@ impl ::core::default::Default for NapComponentRegistrationInfo {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct NapNotifyType(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const napNotifyTypeUnknown: NapNotifyType = NapNotifyType(0i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const napNotifyTypeServiceState: NapNotifyType = NapNotifyType(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const napNotifyTypeQuarState: NapNotifyType = NapNotifyType(2i32);
-impl ::core::marker::Copy for NapNotifyType {}
-impl ::core::clone::Clone for NapNotifyType {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for NapNotifyType {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for NapNotifyType {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for NapNotifyType {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("NapNotifyType").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct NapTracingLevel(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const tracingLevelUndefined: NapTracingLevel = NapTracingLevel(0i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const tracingLevelBasic: NapTracingLevel = NapTracingLevel(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const tracingLevelAdvanced: NapTracingLevel = NapTracingLevel(2i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const tracingLevelDebug: NapTracingLevel = NapTracingLevel(3i32);
-impl ::core::marker::Copy for NapTracingLevel {}
-impl ::core::clone::Clone for NapTracingLevel {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for NapTracingLevel {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for NapTracingLevel {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for NapTracingLevel {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("NapTracingLevel").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
 pub struct NetworkSoH {
@@ -531,12 +584,12 @@ impl ::core::fmt::Debug for NetworkSoH {
         f.debug_struct("NetworkSoH").field("size", &self.size).field("data", &self.data).finish()
     }
 }
-unsafe impl ::windows::core::Abi for NetworkSoH {
-    type Abi = Self;
+impl ::windows_core::TypeKind for NetworkSoH {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for NetworkSoH {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NetworkSoH>()) == 0 }
+        self.size == other.size && self.data == other.data
     }
 }
 impl ::core::cmp::Eq for NetworkSoH {}
@@ -562,12 +615,12 @@ impl ::core::fmt::Debug for PrivateData {
         f.debug_struct("PrivateData").field("size", &self.size).field("data", &self.data).finish()
     }
 }
-unsafe impl ::windows::core::Abi for PrivateData {
-    type Abi = Self;
+impl ::windows_core::TypeKind for PrivateData {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for PrivateData {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<PrivateData>()) == 0 }
+        self.size == other.size && self.data == other.data
     }
 }
 impl ::core::cmp::Eq for PrivateData {}
@@ -576,38 +629,11 @@ impl ::core::default::Default for PrivateData {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct RemoteConfigurationType(pub i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const remoteConfigTypeMachine: RemoteConfigurationType = RemoteConfigurationType(1i32);
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const remoteConfigTypeConfigBlob: RemoteConfigurationType = RemoteConfigurationType(2i32);
-impl ::core::marker::Copy for RemoteConfigurationType {}
-impl ::core::clone::Clone for RemoteConfigurationType {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for RemoteConfigurationType {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for RemoteConfigurationType {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for RemoteConfigurationType {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("RemoteConfigurationType").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
 pub struct ResultCodes {
     pub count: u16,
-    pub results: *mut ::windows::core::HRESULT,
+    pub results: *mut ::windows_core::HRESULT,
 }
 impl ::core::marker::Copy for ResultCodes {}
 impl ::core::clone::Clone for ResultCodes {
@@ -620,12 +646,12 @@ impl ::core::fmt::Debug for ResultCodes {
         f.debug_struct("ResultCodes").field("count", &self.count).field("results", &self.results).finish()
     }
 }
-unsafe impl ::windows::core::Abi for ResultCodes {
-    type Abi = Self;
+impl ::windows_core::TypeKind for ResultCodes {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for ResultCodes {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<ResultCodes>()) == 0 }
+        self.count == other.count && self.results == other.results
     }
 }
 impl ::core::cmp::Eq for ResultCodes {}
@@ -651,12 +677,12 @@ impl ::core::fmt::Debug for SoH {
         f.debug_struct("SoH").field("count", &self.count).field("attributes", &self.attributes).finish()
     }
 }
-unsafe impl ::windows::core::Abi for SoH {
-    type Abi = Self;
+impl ::windows_core::TypeKind for SoH {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for SoH {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SoH>()) == 0 }
+        self.count == other.count && self.attributes == other.attributes
     }
 }
 impl ::core::cmp::Eq for SoH {}
@@ -683,12 +709,12 @@ impl ::core::fmt::Debug for SoHAttribute {
         f.debug_struct("SoHAttribute").field("type", &self.r#type).field("size", &self.size).field("value", &self.value).finish()
     }
 }
-unsafe impl ::windows::core::Abi for SoHAttribute {
-    type Abi = Self;
+impl ::windows_core::TypeKind for SoHAttribute {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for SoHAttribute {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SoHAttribute>()) == 0 }
+        self.r#type == other.r#type && self.size == other.size && self.value == other.value
     }
 }
 impl ::core::cmp::Eq for SoHAttribute {}
@@ -716,12 +742,12 @@ impl ::core::fmt::Debug for SystemHealthAgentState {
         f.debug_struct("SystemHealthAgentState").field("id", &self.id).field("shaResultCodes", &self.shaResultCodes).field("failureCategory", &self.failureCategory).field("fixupInfo", &self.fixupInfo).finish()
     }
 }
-unsafe impl ::windows::core::Abi for SystemHealthAgentState {
-    type Abi = Self;
+impl ::windows_core::TypeKind for SystemHealthAgentState {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for SystemHealthAgentState {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SystemHealthAgentState>()) == 0 }
+        self.id == other.id && self.shaResultCodes == other.shaResultCodes && self.failureCategory == other.failureCategory && self.fixupInfo == other.fixupInfo
     }
 }
 impl ::core::cmp::Eq for SystemHealthAgentState {}
@@ -730,31 +756,3 @@ impl ::core::default::Default for SystemHealthAgentState {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const failureCategoryCount: u32 = 5u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const freshSoHRequest: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxConnectionCountPerEnforcer: u32 = 20u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxEnforcerCount: u32 = 20u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxNetworkSoHSize: u32 = 4000u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxPrivateDataSize: u32 = 200u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxSoHAttributeCount: u32 = 100u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxSoHAttributeSize: u32 = 4000u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxStringLength: u32 = 1024u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const maxSystemHealthEntityCount: u32 = 20u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const minNetworkSoHSize: u32 = 12u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const percentageNotSupported: u32 = 101u32;
-#[doc = "*Required features: `\"Win32_Security_NetworkAccessProtection\"`*"]
-pub const shaFixup: u32 = 1u32;
-#[cfg(feature = "implement")]
-::core::include!("impl.rs");
