@@ -1,25 +1,20 @@
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 #[repr(transparent)]
-pub struct IObjectArray(::windows::core::IUnknown);
+pub struct IObjectArray(::windows_core::IUnknown);
 impl IObjectArray {
-    pub unsafe fn GetCount(&self) -> ::windows::core::Result<u32> {
-        let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Vtable::vtable(self).GetCount)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
+    pub unsafe fn GetCount(&self) -> ::windows_core::Result<u32> {
+        let mut result__ = ::std::mem::zeroed();
+        (::windows_core::Interface::vtable(self).GetCount)(::windows_core::Interface::as_raw(self), &mut result__).from_abi(result__)
     }
-    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows::core::Result<T>
+    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows_core::Result<T>
     where
-        T: ::windows::core::Interface,
+        T: ::windows_core::ComInterface,
     {
-        let mut result__ = ::core::option::Option::None;
-        (::windows::core::Vtable::vtable(self).GetAt)(::windows::core::Vtable::as_raw(self), uiindex, &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
-    }
-}
-::windows::core::interface_hierarchy!(IObjectArray, ::windows::core::IUnknown);
-impl ::core::clone::Clone for IObjectArray {
-    fn clone(&self) -> Self {
-        Self(self.0.clone())
+        let mut result__ = ::std::ptr::null_mut();
+        (::windows_core::Interface::vtable(self).GetAt)(::windows_core::Interface::as_raw(self), uiindex, &<T as ::windows_core::ComInterface>::IID, &mut result__).from_abi(result__)
     }
 }
+::windows_core::imp::interface_hierarchy!(IObjectArray, ::windows_core::IUnknown);
 impl ::core::cmp::PartialEq for IObjectArray {
     fn eq(&self, other: &Self) -> bool {
         self.0 == other.0
@@ -31,59 +26,59 @@ impl ::core::fmt::Debug for IObjectArray {
         f.debug_tuple("IObjectArray").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Vtable for IObjectArray {
+unsafe impl ::windows_core::Interface for IObjectArray {
     type Vtable = IObjectArray_Vtbl;
 }
-unsafe impl ::windows::core::Interface for IObjectArray {
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x92ca9dcd_5622_4bba_a805_5e9f541bd8c9);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IObjectArray_Vtbl {
-    pub base__: ::windows::core::IUnknown_Vtbl,
-    pub GetCount: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, pcobjects: *mut u32) -> ::windows::core::HRESULT,
-    pub GetAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32, riid: *const ::windows::core::GUID, ppv: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-}
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-#[repr(transparent)]
-pub struct IObjectCollection(::windows::core::IUnknown);
-impl IObjectCollection {
-    pub unsafe fn GetCount(&self) -> ::windows::core::Result<u32> {
-        let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Vtable::vtable(self).base__.GetCount)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
-    }
-    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows::core::Result<T>
-    where
-        T: ::windows::core::Interface,
-    {
-        let mut result__ = ::core::option::Option::None;
-        (::windows::core::Vtable::vtable(self).base__.GetAt)(::windows::core::Vtable::as_raw(self), uiindex, &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
-    }
-    pub unsafe fn AddObject<'a, P0>(&self, punk: P0) -> ::windows::core::Result<()>
-    where
-        P0: ::std::convert::Into<::windows::core::InParam<'a, ::windows::core::IUnknown>>,
-    {
-        (::windows::core::Vtable::vtable(self).AddObject)(::windows::core::Vtable::as_raw(self), punk.into().abi()).ok()
-    }
-    pub unsafe fn AddFromArray<'a, P0>(&self, poasource: P0) -> ::windows::core::Result<()>
-    where
-        P0: ::std::convert::Into<::windows::core::InParam<'a, IObjectArray>>,
-    {
-        (::windows::core::Vtable::vtable(self).AddFromArray)(::windows::core::Vtable::as_raw(self), poasource.into().abi()).ok()
-    }
-    pub unsafe fn RemoveObjectAt(&self, uiindex: u32) -> ::windows::core::Result<()> {
-        (::windows::core::Vtable::vtable(self).RemoveObjectAt)(::windows::core::Vtable::as_raw(self), uiindex).ok()
-    }
-    pub unsafe fn Clear(&self) -> ::windows::core::Result<()> {
-        (::windows::core::Vtable::vtable(self).Clear)(::windows::core::Vtable::as_raw(self)).ok()
-    }
-}
-::windows::core::interface_hierarchy!(IObjectCollection, ::windows::core::IUnknown, IObjectArray);
-impl ::core::clone::Clone for IObjectCollection {
+impl ::core::clone::Clone for IObjectArray {
     fn clone(&self) -> Self {
         Self(self.0.clone())
     }
 }
+unsafe impl ::windows_core::ComInterface for IObjectArray {
+    const IID: ::windows_core::GUID = ::windows_core::GUID::from_u128(0x92ca9dcd_5622_4bba_a805_5e9f541bd8c9);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IObjectArray_Vtbl {
+    pub base__: ::windows_core::IUnknown_Vtbl,
+    pub GetCount: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, pcobjects: *mut u32) -> ::windows_core::HRESULT,
+    pub GetAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32, riid: *const ::windows_core::GUID, ppv: *mut *mut ::core::ffi::c_void) -> ::windows_core::HRESULT,
+}
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+#[repr(transparent)]
+pub struct IObjectCollection(::windows_core::IUnknown);
+impl IObjectCollection {
+    pub unsafe fn GetCount(&self) -> ::windows_core::Result<u32> {
+        let mut result__ = ::std::mem::zeroed();
+        (::windows_core::Interface::vtable(self).base__.GetCount)(::windows_core::Interface::as_raw(self), &mut result__).from_abi(result__)
+    }
+    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows_core::Result<T>
+    where
+        T: ::windows_core::ComInterface,
+    {
+        let mut result__ = ::std::ptr::null_mut();
+        (::windows_core::Interface::vtable(self).base__.GetAt)(::windows_core::Interface::as_raw(self), uiindex, &<T as ::windows_core::ComInterface>::IID, &mut result__).from_abi(result__)
+    }
+    pub unsafe fn AddObject<P0>(&self, punk: P0) -> ::windows_core::Result<()>
+    where
+        P0: ::windows_core::IntoParam<::windows_core::IUnknown>,
+    {
+        (::windows_core::Interface::vtable(self).AddObject)(::windows_core::Interface::as_raw(self), punk.into_param().abi()).ok()
+    }
+    pub unsafe fn AddFromArray<P0>(&self, poasource: P0) -> ::windows_core::Result<()>
+    where
+        P0: ::windows_core::IntoParam<IObjectArray>,
+    {
+        (::windows_core::Interface::vtable(self).AddFromArray)(::windows_core::Interface::as_raw(self), poasource.into_param().abi()).ok()
+    }
+    pub unsafe fn RemoveObjectAt(&self, uiindex: u32) -> ::windows_core::Result<()> {
+        (::windows_core::Interface::vtable(self).RemoveObjectAt)(::windows_core::Interface::as_raw(self), uiindex).ok()
+    }
+    pub unsafe fn Clear(&self) -> ::windows_core::Result<()> {
+        (::windows_core::Interface::vtable(self).Clear)(::windows_core::Interface::as_raw(self)).ok()
+    }
+}
+::windows_core::imp::interface_hierarchy!(IObjectCollection, ::windows_core::IUnknown, IObjectArray);
 impl ::core::cmp::PartialEq for IObjectCollection {
     fn eq(&self, other: &Self) -> bool {
         self.0 == other.0
@@ -95,22 +90,29 @@ impl ::core::fmt::Debug for IObjectCollection {
         f.debug_tuple("IObjectCollection").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Vtable for IObjectCollection {
+unsafe impl ::windows_core::Interface for IObjectCollection {
     type Vtable = IObjectCollection_Vtbl;
 }
-unsafe impl ::windows::core::Interface for IObjectCollection {
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x5632b1a4_e38a_400a_928a_d4cd63230295);
+impl ::core::clone::Clone for IObjectCollection {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+unsafe impl ::windows_core::ComInterface for IObjectCollection {
+    const IID: ::windows_core::GUID = ::windows_core::GUID::from_u128(0x5632b1a4_e38a_400a_928a_d4cd63230295);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IObjectCollection_Vtbl {
     pub base__: IObjectArray_Vtbl,
-    pub AddObject: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, punk: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-    pub AddFromArray: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, poasource: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-    pub RemoveObjectAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32) -> ::windows::core::HRESULT,
-    pub Clear: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+    pub AddObject: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, punk: *mut ::core::ffi::c_void) -> ::windows_core::HRESULT,
+    pub AddFromArray: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, poasource: *mut ::core::ffi::c_void) -> ::windows_core::HRESULT,
+    pub RemoveObjectAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32) -> ::windows_core::HRESULT,
+    pub Clear: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows_core::HRESULT,
 }
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const DEVICE_SCALE_FACTOR_INVALID: DEVICE_SCALE_FACTOR = DEVICE_SCALE_FACTOR(0i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub const PERCEIVEDFLAG_GDIPLUS: u32 = 16u32;
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub const PERCEIVEDFLAG_HARDCODED: u32 = 2u32;
@@ -125,11 +127,37 @@ pub const PERCEIVEDFLAG_WMSDK: u32 = 32u32;
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub const PERCEIVEDFLAG_ZIPFOLDER: u32 = 64u32;
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct DEVICE_SCALE_FACTOR(pub i32);
+pub const PERCEIVED_TYPE_APPLICATION: PERCEIVED = PERCEIVED(8i32);
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const DEVICE_SCALE_FACTOR_INVALID: DEVICE_SCALE_FACTOR = DEVICE_SCALE_FACTOR(0i32);
+pub const PERCEIVED_TYPE_AUDIO: PERCEIVED = PERCEIVED(3i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_COMPRESSED: PERCEIVED = PERCEIVED(5i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_CONTACTS: PERCEIVED = PERCEIVED(10i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_CUSTOM: PERCEIVED = PERCEIVED(-3i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_DOCUMENT: PERCEIVED = PERCEIVED(6i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_FIRST: PERCEIVED = PERCEIVED(-3i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_FOLDER: PERCEIVED = PERCEIVED(-1i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_GAMEMEDIA: PERCEIVED = PERCEIVED(9i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_IMAGE: PERCEIVED = PERCEIVED(2i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_LAST: PERCEIVED = PERCEIVED(10i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_SYSTEM: PERCEIVED = PERCEIVED(7i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_TEXT: PERCEIVED = PERCEIVED(1i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_UNKNOWN: PERCEIVED = PERCEIVED(0i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_UNSPECIFIED: PERCEIVED = PERCEIVED(-2i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVED_TYPE_VIDEO: PERCEIVED = PERCEIVED(4i32);
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub const SCALE_100_PERCENT: DEVICE_SCALE_FACTOR = DEVICE_SCALE_FACTOR(100i32);
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
@@ -162,6 +190,56 @@ pub const SCALE_400_PERCENT: DEVICE_SCALE_FACTOR = DEVICE_SCALE_FACTOR(400i32);
 pub const SCALE_450_PERCENT: DEVICE_SCALE_FACTOR = DEVICE_SCALE_FACTOR(450i32);
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub const SCALE_500_PERCENT: DEVICE_SCALE_FACTOR = DEVICE_SCALE_FACTOR(500i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_BATCHREAD: SHCOLSTATE = SHCOLSTATE(131072i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_DEFAULT: SHCOLSTATE = SHCOLSTATE(0i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_DISPLAYMASK: SHCOLSTATE = SHCOLSTATE(61440i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_EXTENDED: SHCOLSTATE = SHCOLSTATE(64i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_FIXED_RATIO: SHCOLSTATE = SHCOLSTATE(16384i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_FIXED_WIDTH: SHCOLSTATE = SHCOLSTATE(4096i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_HIDDEN: SHCOLSTATE = SHCOLSTATE(256i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_NODPISCALE: SHCOLSTATE = SHCOLSTATE(8192i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_NOSORTBYFOLDERNESS: SHCOLSTATE = SHCOLSTATE(2048i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_NO_GROUPBY: SHCOLSTATE = SHCOLSTATE(262144i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_ONBYDEFAULT: SHCOLSTATE = SHCOLSTATE(16i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_PREFER_FMTCMP: SHCOLSTATE = SHCOLSTATE(1024i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_PREFER_VARCMP: SHCOLSTATE = SHCOLSTATE(512i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_SECONDARYUI: SHCOLSTATE = SHCOLSTATE(128i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_SLOW: SHCOLSTATE = SHCOLSTATE(32i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_TYPEMASK: SHCOLSTATE = SHCOLSTATE(15i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_TYPE_DATE: SHCOLSTATE = SHCOLSTATE(3i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_TYPE_INT: SHCOLSTATE = SHCOLSTATE(2i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_TYPE_STR: SHCOLSTATE = SHCOLSTATE(1i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const SHCOLSTATE_VIEWONLY: SHCOLSTATE = SHCOLSTATE(65536i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const STRRET_CSTR: STRRET_TYPE = STRRET_TYPE(2i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const STRRET_OFFSET: STRRET_TYPE = STRRET_TYPE(1i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const STRRET_WSTR: STRRET_TYPE = STRRET_TYPE(0i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct DEVICE_SCALE_FACTOR(pub i32);
 impl ::core::marker::Copy for DEVICE_SCALE_FACTOR {}
 impl ::core::clone::Clone for DEVICE_SCALE_FACTOR {
     fn clone(&self) -> Self {
@@ -173,8 +251,8 @@ impl ::core::default::Default for DEVICE_SCALE_FACTOR {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for DEVICE_SCALE_FACTOR {
-    type Abi = Self;
+impl ::windows_core::TypeKind for DEVICE_SCALE_FACTOR {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::fmt::Debug for DEVICE_SCALE_FACTOR {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -185,38 +263,6 @@ impl ::core::fmt::Debug for DEVICE_SCALE_FACTOR {
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct PERCEIVED(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_FIRST: PERCEIVED = PERCEIVED(-3i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_CUSTOM: PERCEIVED = PERCEIVED(-3i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_UNSPECIFIED: PERCEIVED = PERCEIVED(-2i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_FOLDER: PERCEIVED = PERCEIVED(-1i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_UNKNOWN: PERCEIVED = PERCEIVED(0i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_TEXT: PERCEIVED = PERCEIVED(1i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_IMAGE: PERCEIVED = PERCEIVED(2i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_AUDIO: PERCEIVED = PERCEIVED(3i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_VIDEO: PERCEIVED = PERCEIVED(4i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_COMPRESSED: PERCEIVED = PERCEIVED(5i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_DOCUMENT: PERCEIVED = PERCEIVED(6i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_SYSTEM: PERCEIVED = PERCEIVED(7i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_APPLICATION: PERCEIVED = PERCEIVED(8i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_GAMEMEDIA: PERCEIVED = PERCEIVED(9i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_CONTACTS: PERCEIVED = PERCEIVED(10i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVED_TYPE_LAST: PERCEIVED = PERCEIVED(10i32);
 impl ::core::marker::Copy for PERCEIVED {}
 impl ::core::clone::Clone for PERCEIVED {
     fn clone(&self) -> Self {
@@ -228,8 +274,8 @@ impl ::core::default::Default for PERCEIVED {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for PERCEIVED {
-    type Abi = Self;
+impl ::windows_core::TypeKind for PERCEIVED {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::fmt::Debug for PERCEIVED {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -240,46 +286,6 @@ impl ::core::fmt::Debug for PERCEIVED {
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct SHCOLSTATE(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_DEFAULT: SHCOLSTATE = SHCOLSTATE(0i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_TYPE_STR: SHCOLSTATE = SHCOLSTATE(1i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_TYPE_INT: SHCOLSTATE = SHCOLSTATE(2i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_TYPE_DATE: SHCOLSTATE = SHCOLSTATE(3i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_TYPEMASK: SHCOLSTATE = SHCOLSTATE(15i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_ONBYDEFAULT: SHCOLSTATE = SHCOLSTATE(16i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_SLOW: SHCOLSTATE = SHCOLSTATE(32i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_EXTENDED: SHCOLSTATE = SHCOLSTATE(64i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_SECONDARYUI: SHCOLSTATE = SHCOLSTATE(128i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_HIDDEN: SHCOLSTATE = SHCOLSTATE(256i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_PREFER_VARCMP: SHCOLSTATE = SHCOLSTATE(512i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_PREFER_FMTCMP: SHCOLSTATE = SHCOLSTATE(1024i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_NOSORTBYFOLDERNESS: SHCOLSTATE = SHCOLSTATE(2048i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_VIEWONLY: SHCOLSTATE = SHCOLSTATE(65536i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_BATCHREAD: SHCOLSTATE = SHCOLSTATE(131072i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_NO_GROUPBY: SHCOLSTATE = SHCOLSTATE(262144i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_FIXED_WIDTH: SHCOLSTATE = SHCOLSTATE(4096i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_NODPISCALE: SHCOLSTATE = SHCOLSTATE(8192i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_FIXED_RATIO: SHCOLSTATE = SHCOLSTATE(16384i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const SHCOLSTATE_DISPLAYMASK: SHCOLSTATE = SHCOLSTATE(61440i32);
 impl ::core::marker::Copy for SHCOLSTATE {}
 impl ::core::clone::Clone for SHCOLSTATE {
     fn clone(&self) -> Self {
@@ -291,8 +297,8 @@ impl ::core::default::Default for SHCOLSTATE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for SHCOLSTATE {
-    type Abi = Self;
+impl ::windows_core::TypeKind for SHCOLSTATE {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::fmt::Debug for SHCOLSTATE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -303,12 +309,6 @@ impl ::core::fmt::Debug for SHCOLSTATE {
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct STRRET_TYPE(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const STRRET_WSTR: STRRET_TYPE = STRRET_TYPE(0i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const STRRET_OFFSET: STRRET_TYPE = STRRET_TYPE(1i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const STRRET_CSTR: STRRET_TYPE = STRRET_TYPE(2i32);
 impl ::core::marker::Copy for STRRET_TYPE {}
 impl ::core::clone::Clone for STRRET_TYPE {
     fn clone(&self) -> Self {
@@ -320,8 +320,8 @@ impl ::core::default::Default for STRRET_TYPE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for STRRET_TYPE {
-    type Abi = Self;
+impl ::windows_core::TypeKind for STRRET_TYPE {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::fmt::Debug for STRRET_TYPE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -331,8 +331,8 @@ impl ::core::fmt::Debug for STRRET_TYPE {
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub struct COMDLG_FILTERSPEC {
-    pub pszName: ::windows::core::PCWSTR,
-    pub pszSpec: ::windows::core::PCWSTR,
+    pub pszName: ::windows_core::PCWSTR,
+    pub pszSpec: ::windows_core::PCWSTR,
 }
 impl ::core::marker::Copy for COMDLG_FILTERSPEC {}
 impl ::core::clone::Clone for COMDLG_FILTERSPEC {
@@ -345,12 +345,12 @@ impl ::core::fmt::Debug for COMDLG_FILTERSPEC {
         f.debug_struct("COMDLG_FILTERSPEC").field("pszName", &self.pszName).field("pszSpec", &self.pszSpec).finish()
     }
 }
-unsafe impl ::windows::core::Abi for COMDLG_FILTERSPEC {
-    type Abi = Self;
+impl ::windows_core::TypeKind for COMDLG_FILTERSPEC {
+    type TypeKind = ::windows_core::CopyType;
 }
 impl ::core::cmp::PartialEq for COMDLG_FILTERSPEC {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<COMDLG_FILTERSPEC>()) == 0 }
+        self.pszName == other.pszName && self.pszSpec == other.pszSpec
     }
 }
 impl ::core::cmp::Eq for COMDLG_FILTERSPEC {}
@@ -370,15 +370,9 @@ impl ::core::clone::Clone for ITEMIDLIST {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for ITEMIDLIST {
-    type Abi = Self;
+impl ::windows_core::TypeKind for ITEMIDLIST {
+    type TypeKind = ::windows_core::CopyType;
 }
-impl ::core::cmp::PartialEq for ITEMIDLIST {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<ITEMIDLIST>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for ITEMIDLIST {}
 impl ::core::default::Default for ITEMIDLIST {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -397,15 +391,9 @@ impl ::core::clone::Clone for SHELLDETAILS {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for SHELLDETAILS {
-    type Abi = Self;
+impl ::windows_core::TypeKind for SHELLDETAILS {
+    type TypeKind = ::windows_core::CopyType;
 }
-impl ::core::cmp::PartialEq for SHELLDETAILS {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SHELLDETAILS>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for SHELLDETAILS {}
 impl ::core::default::Default for SHELLDETAILS {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -423,15 +411,9 @@ impl ::core::clone::Clone for SHITEMID {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for SHITEMID {
-    type Abi = Self;
+impl ::windows_core::TypeKind for SHITEMID {
+    type TypeKind = ::windows_core::CopyType;
 }
-impl ::core::cmp::PartialEq for SHITEMID {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SHITEMID>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for SHITEMID {}
 impl ::core::default::Default for SHITEMID {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -449,15 +431,9 @@ impl ::core::clone::Clone for STRRET {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for STRRET {
-    type Abi = Self;
+impl ::windows_core::TypeKind for STRRET {
+    type TypeKind = ::windows_core::CopyType;
 }
-impl ::core::cmp::PartialEq for STRRET {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<STRRET>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for STRRET {}
 impl ::core::default::Default for STRRET {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -466,7 +442,7 @@ impl ::core::default::Default for STRRET {
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub union STRRET_0 {
-    pub pOleStr: ::windows::core::PWSTR,
+    pub pOleStr: ::windows_core::PWSTR,
     pub uOffset: u32,
     pub cStr: [u8; 260],
 }
@@ -476,15 +452,9 @@ impl ::core::clone::Clone for STRRET_0 {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for STRRET_0 {
-    type Abi = Self;
+impl ::windows_core::TypeKind for STRRET_0 {
+    type TypeKind = ::windows_core::CopyType;
 }
-impl ::core::cmp::PartialEq for STRRET_0 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<STRRET_0>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for STRRET_0 {}
 impl ::core::default::Default for STRRET_0 {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
